@@ -25,19 +25,38 @@ pub enum SubCommands {
     /// List all installed kernels
     #[clap(display_order = 6)]
     ListInstalled,
+    /// Configure systemd-boot
+    #[clap(display_order = 7)]
+    Config,
+    #[clap(display_order = 8)]
+    SetDefault(SetDefault),
+    #[clap(display_order = 9)]
+    SetTimeout(SetTimeout),
 }
 
-/// Install the kernel specified
+/// Install the kernels specified
 #[derive(Parser, Debug)]
 pub struct Install {
-    pub target: Option<String>,
+    pub targets: Vec<String>,
     /// Force overwrite the entry config or not
     #[clap(long, short)]
     pub force: bool,
 }
 
-/// Remove the kernel specified
+/// Remove the kernels specified
 #[derive(Parser, Debug)]
 pub struct Remove {
+    pub targets: Vec<String>,
+}
+
+/// Set the default kernel
+#[derive(Parser, Debug)]
+pub struct SetDefault {
     pub target: Option<String>,
 }
+
+/// Set the boot menu timeout
+#[derive(Parser, Debug)]
+pub struct SetTimeout {
+    pub timeout: Option<u32>,
+}
